
.. DO NOT EDIT.
.. THIS FILE WAS AUTOMATICALLY GENERATED BY SPHINX-GALLERY.
.. TO MAKE CHANGES, EDIT THE SOURCE PYTHON FILE:
.. "_as_gen/sph/run_track_particles.py"
.. LINE NUMBERS ARE GIVEN BELOW.

.. only:: html

    .. note::
        :class: sphx-glr-download-link-note

        :ref:`Go to the end <sphx_glr_download__as_gen_sph_run_track_particles.py>`
        to download the full example code.

.. rst-class:: sphx-glr-example-title

.. _sphx_glr__as_gen_sph_run_track_particles.py:


Tracking particles by id in SPH
===============================

This simple example shows how to track particles by id

.. GENERATED FROM PYTHON SOURCE LINES 7-26

.. code-block:: Python
   :lineno-start: 9



    import shamrock

    # Particle tracking is an experimental feature
    shamrock.enable_experimental_features()

    # If we use the shamrock executable to run this script instead of the python interpreter,
    # we should not initialize the system as the shamrock executable needs to handle specific MPI logic
    if not shamrock.sys.is_initialized():
        shamrock.change_loglevel(1)
        shamrock.sys.init("0:0")


    def is_in_sphere(pt):
        x, y, z = pt
        return (x**2 + y**2 + z**2) < 1









.. GENERATED FROM PYTHON SOURCE LINES 28-29

Setup parameters

.. GENERATED FROM PYTHON SOURCE LINES 29-38

.. code-block:: Python
   :lineno-start: 30


    dr = 0.1
    pmass = 1

    C_cour = 0.3
    C_force = 0.25

    bsize = 4








.. GENERATED FROM PYTHON SOURCE LINES 39-40

Setup

.. GENERATED FROM PYTHON SOURCE LINES 40-88

.. code-block:: Python
   :lineno-start: 41


    ctx = shamrock.Context()
    ctx.pdata_layout_new()

    model = shamrock.get_Model_SPH(context=ctx, vector_type="f64_3", sph_kernel="M4")

    cfg = model.gen_default_config()
    # cfg.set_artif_viscosity_VaryingMM97(alpha_min = 0.1,alpha_max = 1,sigma_decay = 0.1, alpha_u = 1, beta_AV = 2)
    # cfg.set_artif_viscosity_ConstantDisc(alpha_u=alpha_u, alpha_AV=alpha_AV, beta_AV=beta_AV)
    # cfg.set_eos_locally_isothermalLP07(cs0=cs0, q=q, r0=r0)
    cfg.set_artif_viscosity_VaryingCD10(
        alpha_min=0.0, alpha_max=1, sigma_decay=0.1, alpha_u=1, beta_AV=2
    )
    cfg.set_particle_tracking(True)
    cfg.set_boundary_periodic()
    cfg.set_eos_adiabatic(1.00001)
    cfg.print_status()
    model.set_solver_config(cfg)

    model.init_scheduler(int(1e7), 1)

    bmin = (-bsize, -bsize, -bsize)
    bmax = (bsize, bsize, bsize)
    model.resize_simulation_box(bmin, bmax)

    model.set_particle_mass(pmass)

    setup = model.get_setup()
    lat = setup.make_generator_lattice_hcp(dr, (-bsize, -bsize, -bsize), (bsize, bsize, bsize))

    thesphere = setup.make_modifier_filter(parent=lat, filter=is_in_sphere)

    offset_sphere = setup.make_modifier_offset(
        parent=thesphere, offset_position=(3.0, 3.0, 3.0), offset_velocity=(-1.0, -1.0, -1.0)
    )

    setup.apply_setup(offset_sphere)

    model.set_value_in_a_box("uint", "f64", 1, bmin, bmax)

    model.set_cfl_cour(C_cour)
    model.set_cfl_force(C_force)

    model.change_htolerance(1.3)
    model.timestep()
    model.change_htolerance(1.1)






.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    ----- SPH Solver configuration ----- 
    units :  
    not set 
    part mass 0 ( can be changed using .set_part_mass() ) 
    cfl force 0 
    cfl courant 0 
    --- artificial viscosity config 
      Config Type : VaryingCD10 (Cullen & Dehnen 2010) 
      alpha_min   = 0 
      alpha_max   = 1 
      sigma_decay = 0.1 
      alpha_u     = 1 
      beta_AV     = 2 
    --- artificial viscosity config (deduced) 
    ------------- 
    EOS config f64_3 : 
    adiabatic :  
    gamma 1.00001 
    --- Bondaries config 
      Config Type : Periodic boundaries 
    --- Bondaries config config (deduced) 
    ------------- 
    ------------------------------------ 

    ---------------------------- WARNING ----------------------------
    Warning: Experimental features are enabled
    ----------------------------------------------------------------- 
    Info: pushing data in scheduler, N = 735                              [DataInserterUtility][rank=0] 
    Info: reattributing data ...                                          [DataInserterUtility][rank=0] 
    Info: reattributing data done in  1639.95 us                          [DataInserterUtility][rank=0] 
    Info: Compute load ...                                                [DataInserterUtility][rank=0] 
    Info: run scheduler step ...                                          [DataInserterUtility][rank=0] 
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 3.45 us    (42.6%)  
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 735 min = 735                              [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 735 min = 735                         [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 735
        max = 735
        avg = 735
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1482.00 ns (0.4%)
       patch tree reduce : 972.00 ns  (0.2%)
       gen split merge   : 701.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 902.00 ns  (0.2%)
       LB compute        : 401.28 us  (97.3%)
       LB move op cnt    : 0
       LB apply          : 3.29 us    (0.8%)  
    Info: the setup took : 0.062782576 s                                            [SPH setup][rank=0] 
    ---------------- t = 0, dt = 0 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 735 min = 735                              [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 735 min = 735                         [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 735
        max = 735
        avg = 735
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 3.04 us    (0.7%)
       patch tree reduce : 550.00 ns  (0.1%)
       gen split merge   : 461.00 ns  (0.1%)
       split / merge op  : 0/0
       apply split merge : 350.00 ns  (0.1%)
       LB compute        : 422.94 us  (97.5%)
       LB move op cnt    : 0
       LB apply          : 2.39 us    (0.6%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.50 us    (70.1%)  
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.13 unconverged cnt = 735   
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 0.20952380952380953  
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.169 unconverged cnt = 735   
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 0.39319727891156464  
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.21970000000000003 unconverged cnt = 334   
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 0.6585034013605442  
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.28561000000000003 unconverged cnt = 2   
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 1.23265306122449  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 0, max = 1.4912191007870045e-10
      iterations = 3  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (-735,-735,-735)
        sum a = (-1.734723475976807e-18,-2.168404344971009e-19,-1.0842021724855044e-18)
        sum e = 1837.5
        sum de = 2.6020852139652106e-18  
    Info: cfl dt = 0.1305431643141646 cfl multiplier : 0.01                        [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) |  MPI   | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    8.2636e+03    |         735 |   8.894e-02   |    0 % |   1 % |   29.24 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 0 (tsim/hr)                                             [sph::Model][rank=0] 




.. GENERATED FROM PYTHON SOURCE LINES 89-90

Init history table

.. GENERATED FROM PYTHON SOURCE LINES 90-113

.. code-block:: Python
   :lineno-start: 90

    part_history = []

    data = ctx.collect_data()
    print(data)

    part_history = [{} for i in range(len(data["xyz"]))]
    for i in range(len(data["xyz"])):
        part_history[data["part_id"][i]] = {
            "x": [data["xyz"][i][0]],
            "y": [data["xyz"][i][1]],
            "z": [data["xyz"][i][2]],
        }


    def append_to_history():
        data = ctx.collect_data()

        for i in range(len(data["xyz"])):
            part_history[data["part_id"][i]]["x"].append(data["xyz"][i][0])
            part_history[data["part_id"][i]]["y"].append(data["xyz"][i][1])
            part_history[data["part_id"][i]]["z"].append(data["xyz"][i][2])






.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    adding ->  xyz
    adding ->  vxyz
    adding ->  axyz
    adding ->  axyz_ext
    adding ->  hpart
    adding ->  part_id
    adding ->  uint
    adding ->  duint
    adding ->  alpha_AV
    adding ->  divv
    adding ->  dtdivv
    adding ->  curlv
    adding ->  soundspeed
    {'xyz': array([[2.3       , 2.48038476, 2.67340137],
           [2.4       , 2.30717968, 2.67340137],
           [2.3       , 2.3649147 , 2.83670068],
           ...,
           [3.5       , 3.8660254 , 3.        ],
           [3.5       , 3.75055535, 3.16329932],
           [3.5       , 3.51961524, 3.65319726]], shape=(735, 3)), 'vxyz': array([[-1., -1., -1.],
           [-1., -1., -1.],
           [-1., -1., -1.],
           ...,
           [-1., -1., -1.],
           [-1., -1., -1.],
           [-1., -1., -1.]], shape=(735, 3)), 'axyz': array([[-6.07564493e-05, -4.19305177e-05, -3.33234503e-05],
           [-5.26819605e-05, -7.21000314e-05, -3.19971073e-05],
           [-6.54663258e-05, -6.30451355e-05, -9.79795900e-06],
           ...,
           [ 5.02839018e-05,  8.56177477e-05, -1.69406589e-21],
           [ 4.24596463e-05,  6.12386886e-05,  1.61018811e-05],
           [ 3.96519461e-05,  5.35753755e-05,  6.75477378e-05]],
          shape=(735, 3)), 'axyz_ext': array([[0., 0., 0.],
           [0., 0., 0.],
           [0., 0., 0.],
           ...,
           [0., 0., 0.],
           [0., 0., 0.],
           [0., 0., 0.]], shape=(735, 3)), 'hpart': array([0.24340982, 0.26266205, 0.25527829, 0.25617457, 0.26581476,
           0.24340982, 0.25653232, 0.24634686, 0.26341738, 0.25208943,
           0.22243493, 0.23538249, 0.23538249, 0.21573943, 0.2152501 ,
           0.2152501 , 0.2164275 , 0.21643851, 0.21403115, 0.26581476,
           0.23478299, 0.26206811, 0.2228041 , 0.26133329, 0.24182531,
           0.25208943, 0.22852822, 0.2164275 , 0.22669761, 0.21424214,
           0.22104652, 0.21461491, 0.25425536, 0.23756227, 0.22276011,
           0.26961698, 0.21620613, 0.21666461, 0.21402392, 0.21403115,
           0.25262937, 0.22676156, 0.25262937, 0.22676156, 0.21605986,
           0.26362011, 0.23688837, 0.2162894 , 0.23467853, 0.21453074,
           0.21643851, 0.21509783, 0.21402392, 0.21408423, 0.21403115,
           0.21402392, 0.21402392, 0.21402392, 0.21408423, 0.21402392,
           0.21402392, 0.21430489, 0.21402392, 0.21402392, 0.21402392,
           0.21402392, 0.21402392, 0.21402392, 0.21402392, 0.25527829,
           0.22876116, 0.2414449 , 0.24340982, 0.26266205, 0.25653232,
           0.24634686, 0.22882381, 0.24340982, 0.24830696, 0.22243493,
           0.26341738, 0.25208943, 0.2152501 , 0.2152501 , 0.21421868,
           0.23538249, 0.23538249, 0.21573943, 0.21478168, 0.21403115,
           0.2164275 , 0.21643851, 0.25617457, 0.26581476, 0.27727148,
           0.24182531, 0.2414449 , 0.26133329, 0.21759492, 0.22104652,
           0.21459018, 0.21461491, 0.21402392, 0.22852822, 0.25208943,
           0.2164275 , 0.22669761, 0.21424214, 0.22276011, 0.26961698,
           0.22789307, 0.25425536, 0.23756227, 0.21459018, 0.21403115,
           0.21402392, 0.21620613, 0.21666461, 0.21402392, 0.26581476,
           0.23478299, 0.26206811, 0.2228041 , 0.21403115, 0.21402392,
           0.21402392, 0.21402392, 0.21643851, 0.21402392, 0.21509783,
           0.21408423, 0.21402392, 0.21402392, 0.21402392, 0.21402392,
           0.21408423, 0.21402392, 0.21402392, 0.21402392, 0.21402392,
           0.21430489, 0.21402392, 0.21402392, 0.21402392, 0.21402392,
           0.21402392, 0.21402392, 0.22676156, 0.25262937, 0.22676156,
           0.21605986, 0.25262937, 0.2162894 , 0.26362011, 0.23688837,
           0.21453074, 0.23467853, 0.26206811, 0.23478299, 0.2500656 ,
           0.26596674, 0.22866132, 0.25483063, 0.24970579, 0.22896197,
           0.24704704, 0.22669761, 0.2164275 , 0.21424214, 0.21666461,
           0.21481585, 0.21421868, 0.24346819, 0.21504804, 0.22789226,
           0.24704704, 0.25483063, 0.26513963, 0.22851073, 0.26362011,
           0.25306901, 0.23688837, 0.2162894 , 0.2228041 , 0.21495114,
           0.26362011, 0.2228041 , 0.23688837, 0.23005256, 0.21453074,
           0.21453074, 0.25262937, 0.2162894 , 0.21430489, 0.21402392,
           0.21408423, 0.21402392, 0.21402392, 0.21402392, 0.21402392,
           0.21402392, 0.21402392, 0.21402392, 0.21666461, 0.21430489,
           0.21421868, 0.21402392, 0.21402392, 0.21402392, 0.21402392,
           0.21402392, 0.21402392, 0.21402392, 0.21402392, 0.21408423,
           0.21402392, 0.26206811, 0.23478299, 0.26581476, 0.22676156,
           0.22669761, 0.2164275 , 0.22852853, 0.21424214, 0.21462328,
           0.25208943, 0.26266205, 0.24260903, 0.22104652, 0.21643851,
           0.2164275 , 0.21402392, 0.21403115, 0.23538249, 0.24340982,
           0.25527829, 0.2152501 , 0.24970579, 0.25422217, 0.22227764,
           0.22896197, 0.26596674, 0.22866132, 0.25483063, 0.24413242,
           0.24704704, 0.21481585, 0.21517691, 0.21403115, 0.21421868,
           0.22669761, 0.2164275 , 0.21424214, 0.21666461, 0.22789226,
           0.21497721, 0.24346819, 0.21504804, 0.26206811, 0.23478299,
           0.2500656 , 0.24393798, 0.22851073, 0.24660962, 0.24704704,
           0.25483063, 0.26513963, 0.21402392, 0.21402392, 0.21402392,
           0.21402392, 0.21402392, 0.21402392, 0.21402392, 0.21430489,
           0.21402392, 0.21408423, 0.21402392, 0.21402392, 0.21402392,
           0.21421868, 0.21402392, 0.21402392, 0.21666461, 0.21430489,
           0.21402392, 0.21402392, 0.21402392, 0.21402392, 0.21402392,
           0.21402392, 0.21402392, 0.21402392, 0.21402392, 0.21402392,
           0.21402392, 0.21408423, 0.2162894 , 0.2228041 , 0.21495114,
           0.26362011, 0.25306901, 0.23688837, 0.2228041 , 0.26362011,
           0.21453074, 0.21453074, 0.23688837, 0.23005256, 0.2162894 ,
           0.25262937, 0.21497721, 0.21462328, 0.21759492, 0.21402392,
           0.2164275 , 0.22669761, 0.22852853, 0.21424214, 0.27783542,
           0.24260903, 0.2414449 , 0.22104652, 0.26266205, 0.25208943,
           0.21403115, 0.21459018, 0.21402392, 0.21643851, 0.2164275 ,
           0.21402392, 0.25527829, 0.22876116, 0.2152501 , 0.24340982,
           0.23538249, 0.26206811, 0.23478299, 0.26581476, 0.22676156,
           0.2500656 , 0.2228041 , 0.26206811, 0.23478299, 0.24279659,
           0.23756227, 0.25425536, 0.26961698, 0.21782554, 0.22276011,
           0.21666461, 0.21465663, 0.21402392, 0.21620613, 0.21403115,
           0.26133329, 0.24182531, 0.22669761, 0.21424214, 0.22852822,
           0.21461491, 0.25306901, 0.23688837, 0.26362011, 0.21495114,
           0.2162894 , 0.23005256, 0.23467853, 0.21453074, 0.25262937,
           0.22676156, 0.25262937, 0.21605986, 0.21408423, 0.21402392,
           0.21402392, 0.21430489, 0.21402392, 0.21402392, 0.21402392,
           0.21402392, 0.21402392, 0.21402392, 0.21402392, 0.21402392,
           0.21402392, 0.21408423, 0.21643851, 0.21402392, 0.21402392,
           0.21403115, 0.21402392, 0.21408423, 0.21402392, 0.26581476,
           0.25208943, 0.26266205, 0.2164275 , 0.24340982, 0.22104652,
           0.25527829, 0.25617457, 0.22676156, 0.26581476, 0.23538249,
           0.21509783, 0.21573943, 0.23538249, 0.2152501 , 0.21402392,
           0.2152501 , 0.21402392, 0.21643851, 0.2164275 , 0.21403115,
           0.24340982, 0.24634686, 0.25653232, 0.25208943, 0.26341738,
           0.22243493, 0.26961698, 0.22789307, 0.21782554, 0.22276011,
           0.23756227, 0.24279659, 0.25425536, 0.21421868, 0.21403115,
           0.21402392, 0.21459018, 0.21465663, 0.21666461, 0.21402392,
           0.21620613, 0.2414449 , 0.24182531, 0.26133329, 0.21461491,
           0.21402392, 0.21759492, 0.22669761, 0.21424214, 0.22852822,
           0.2500656 , 0.2228041 , 0.26206811, 0.23478299, 0.21402392,
           0.21402392, 0.21402392, 0.21402392, 0.21402392, 0.21408423,
           0.21402392, 0.21402392, 0.21430489, 0.21402392, 0.21402392,
           0.21402392, 0.21402392, 0.21402392, 0.21402392, 0.21402392,
           0.21402392, 0.21403115, 0.21402392, 0.21408423, 0.21643851,
           0.21402392, 0.21402392, 0.21402392, 0.21402392, 0.21408423,
           0.21495114, 0.2162894 , 0.25306901, 0.23688837, 0.26362011,
           0.21453074, 0.23005256, 0.23467853, 0.22676156, 0.25262937,
           0.21605986, 0.25262937, 0.27727148, 0.2414449 , 0.22104652,
           0.21459018, 0.25527829, 0.22876116, 0.26266205, 0.25208943,
           0.2164275 , 0.24340982, 0.26581476, 0.2152501 , 0.21421868,
           0.21402392, 0.2152501 , 0.23538249, 0.21573943, 0.21509783,
           0.23538249, 0.21402392, 0.21403115, 0.21478168, 0.21402392,
           0.21643851, 0.2164275 , 0.24634686, 0.22882381, 0.25653232,
           0.24340982, 0.22243493, 0.24830696, 0.25208943, 0.26341738,
           0.25617457, 0.22676156, 0.26581476, 0.29617995, 0.23005256,
           0.23467853, 0.23688837, 0.21420737, 0.21453074, 0.21453074,
           0.25262937, 0.21605986, 0.2162894 , 0.23688837, 0.25306901,
           0.21495114, 0.2162894 , 0.26362011, 0.2228041 , 0.21402392,
           0.21402392, 0.21402392, 0.21402392, 0.21402392, 0.21402392,
           0.21402392, 0.21402392, 0.21402392, 0.21402392, 0.21408423,
           0.21402392, 0.21402392, 0.21402392, 0.21402392, 0.21402392,
           0.21408423, 0.21402392, 0.21402392, 0.21430489, 0.21402392,
           0.21402392, 0.22676156, 0.25617457, 0.26581476, 0.23478299,
           0.21509783, 0.21402392, 0.21573943, 0.21643851, 0.2164275 ,
           0.21402392, 0.21403115, 0.23538249, 0.24340982, 0.2152501 ,
           0.24634686, 0.25527829, 0.21424214, 0.22669761, 0.22852853,
           0.21462328, 0.25208943, 0.26266205, 0.22104652, 0.26362011,
           0.23478299, 0.2228041 , 0.26206811, 0.2500656 , 0.21430489,
           0.21424214, 0.21666461, 0.21402392, 0.22669761, 0.2164275 ,
           0.21402392, 0.21421868, 0.21481585, 0.21504804, 0.21666461,
           0.24346819, 0.21421868, 0.22789226, 0.22866132, 0.25483063,
           0.26596674, 0.22896197, 0.24970579, 0.24704704, 0.26206811,
           0.25483063, 0.2164275 , 0.26513963, 0.24704704, 0.22851073,
           0.24260903, 0.21402392, 0.21402392, 0.21402392, 0.21402392,
           0.21402392, 0.21402392, 0.21402392, 0.21402392, 0.21402392,
           0.21402392, 0.21402392, 0.21402392, 0.21402392, 0.21402392,
           0.21402392, 0.21402392, 0.21408423, 0.21402392, 0.21402392,
           0.21402392, 0.21402392, 0.21402392, 0.21402392, 0.21402392,
           0.21402392, 0.21408423, 0.21402392, 0.21402392, 0.21430489,
           0.21402392, 0.21420737, 0.21453074, 0.21453074, 0.23005256,
           0.29617995, 0.23467853, 0.23688837, 0.21605986, 0.2162894 ,
           0.25262937, 0.21495114, 0.2162894 , 0.23688837, 0.25306901,
           0.2228041 , 0.26362011, 0.21402392, 0.21402392, 0.21421868,
           0.21403115, 0.21459018, 0.21402392, 0.21509783, 0.21573943,
           0.21643851, 0.2164275 , 0.22876116, 0.2152501 , 0.24634686,
           0.25527829, 0.24340982, 0.23538249, 0.21402392, 0.21462328,
           0.21759492, 0.21424214, 0.22669761, 0.22852853, 0.2414449 ,
           0.22104652, 0.26266205, 0.25208943, 0.22676156, 0.25617457,
           0.26581476, 0.23478299, 0.21403115, 0.21402392, 0.21402392,
           0.21421868, 0.21481585, 0.21517691, 0.21424214, 0.21430489,
           0.21402392, 0.21666461, 0.22669761, 0.2164275 , 0.21497721,
           0.21421868, 0.22789226, 0.21504804, 0.21666461, 0.24346819,
           0.22227764, 0.22896197, 0.24970579, 0.25422217, 0.22866132,
           0.25483063, 0.26596674, 0.24413242, 0.24704704, 0.23478299,
           0.2228041 , 0.26206811, 0.26362011, 0.2500656 , 0.21497721,
           0.22851073, 0.24660962, 0.24393798, 0.2164275 , 0.25483063,
           0.26513963, 0.24704704, 0.27783542, 0.24260903, 0.26206811]), 'part_id': array([704, 660,  14, 475, 504, 685,  34,  57, 724, 332,  81, 298, 313,
           683,  39,  55, 729, 330,  79, 489, 492, 460, 488, 715,  68, 277,
           663, 702, 280, 706,  12,  16, 318, 712,  65,  24, 659, 276, 701,
            11,  99, 478, 111, 502, 506, 105,  96, 474, 108, 501, 316, 296,
           688, 300,  60,  37,  42, 727, 335, 732,  84, 312, 682, 295,  54,
            36, 329, 726,  78, 196, 419, 375, 619, 575, 216, 239, 400, 600,
           443, 263, 639, 177, 221, 237, 398, 143, 158, 598, 448, 261, 644,
           175, 530, 559, 430, 250, 433, 630, 378, 194, 417, 198, 421, 578,
           122, 617, 125, 621, 247, 206, 429, 163, 627, 374, 193, 416, 574,
           121, 616, 544, 547, 515, 543, 242, 403, 219, 224, 161, 603, 141,
           145, 446, 266, 451, 642, 180, 647, 236, 397, 218, 157, 597, 140,
           260, 445, 174, 641, 533, 350, 557, 561, 362, 529, 356, 347, 556,
           359, 484, 455, 468, 690, 653, 306,   0,  48, 676, 272, 695, 651,
           304,   5,  46, 290, 674,  30, 720, 323, 667,  72,  87, 103,  90,
           458, 482, 486,  95, 471, 100,  86, 454, 481,  92, 467, 270, 656,
           309, 693, 274, 698,   3,  51,   8, 679, 288, 292,  28,  32, 650,
           303, 269, 692,  45,   2, 673, 287,  27, 495, 498, 463, 494, 326,
           718, 670, 722,  75, 285, 711,  19,  22, 322, 666, 717,  71, 282,
           708,  62,  18, 182, 405, 368, 230, 605, 568, 151, 391, 591, 187,
           410, 366, 228, 117, 610, 566, 149, 212, 389, 135, 589, 539, 510,
           523, 439, 254, 382, 635, 168, 582, 371, 185, 408, 233, 190, 413,
           571, 115, 608, 154, 119, 613, 394, 210, 214, 594, 133, 137, 365,
           227, 184, 407, 565, 148, 114, 607, 388, 209, 588, 132, 513, 537,
           541, 338, 354, 341, 526, 346, 509, 536, 351, 337, 522, 343, 437,
           257, 385, 441, 633, 171, 585, 637, 424, 201, 427, 204, 626, 130,
           253, 381, 436, 167, 581, 632, 244, 423, 200, 623, 127, 550, 553,
           518, 549, 462, 491, 461, 490, 320, 714, 319,  25,  67,  66, 279,
           662, 705, 661,  15, 713,  69, 278, 703, 664,  13, 107,  98, 106,
           477, 476, 110, 109, 505,  97, 479, 112, 503, 315, 299, 687, 314,
           684,  59,  41,  56, 731, 334, 331,  83,  80, 297, 317, 689,  38,
            61, 728, 336,  85, 493, 281, 658, 707, 700,  17,  10, 473, 507,
           500, 311, 301, 681, 294,  53,  43,  35, 733, 328, 725,  77, 686,
            58,  40, 333, 730,  82, 207, 432, 249, 248, 629, 165, 164, 377,
           197, 420, 376, 577, 124, 620, 576, 431, 251, 628, 195, 418, 379,
           123, 618, 579, 517, 546, 516, 545, 241, 402, 223, 238, 399, 160,
           602, 144, 159, 599, 450, 265, 262, 646, 179, 176, 220, 243, 404,
           142, 162, 604, 447, 267, 643, 181, 532, 531, 358, 349, 357, 560,
           361, 360, 534, 348, 558, 363, 434, 373, 199, 422, 192, 415, 573,
           126, 622, 615, 548, 235, 396, 225, 217, 156, 596, 146, 139, 452,
           259, 444, 648, 173, 640, 240, 401, 222, 601, 264, 449, 178, 645,
           528, 562, 555, 563,  89, 102, 101, 457, 485, 456,  94, 470, 469,
            88, 104, 483, 459,  93, 472, 273, 655, 308, 697, 652, 305,   7,
            50,  47, 678, 291, 675,  31, 271, 694, 657, 310,   4,  52, 289,
           680,  29, 497, 465, 464, 496, 325, 721, 669, 324, 668,  74,  73,
           284, 710,  21,  64,  63, 719, 327, 671,  76, 283, 709,  20,  91,
           453, 487, 480, 466, 275, 649, 302, 699, 268, 691,   9,  44,   1,
           672, 293, 286,  33,  26, 654, 307, 696,  49,   6, 677, 499, 321,
           723, 665, 716,  70,  23, 370, 189, 412, 232, 367, 229, 570, 118,
           612, 153, 567, 150, 393, 213, 390, 593, 136, 590, 186, 409, 372,
           234, 116, 609, 572, 155, 211, 395, 134, 595, 512, 540, 511, 340,
           734, 353, 352, 525, 524, 345, 538, 514, 339, 355, 527, 344, 440,
           256, 384, 255, 383, 636, 170, 584, 169, 583, 426, 203, 246, 245,
           625, 129, 438, 258, 386, 634, 172, 586, 425, 202, 624, 128, 552,
           520, 519, 551, 364, 191, 414, 226, 183, 406, 564, 120, 614, 147,
           113, 606, 387, 215, 208, 587, 138, 131, 369, 231, 188, 411, 569,
           152, 611, 392, 592, 508, 542, 535, 342, 521, 442, 252, 380, 435,
           638, 166, 580, 631, 428, 205, 554], dtype=uint64), 'uint': array([1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
           1., 1., 1., 1.]), 'duint': array([0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0.]), 'alpha_AV': array([0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0.]), 'divv': array([-0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0., -0.,
           -0., -0., -0., -0., -0., -0., -0.]), 'dtdivv': array([0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
           0., 0., 0., 0.]), 'curlv': array([[-0., -0., -0.],
           [-0., -0., -0.],
           [-0., -0., -0.],
           ...,
           [-0., -0., -0.],
           [-0., -0., -0.],
           [-0., -0., -0.]], shape=(735, 3)), 'soundspeed': array([0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229,
           0.00316229, 0.00316229, 0.00316229, 0.00316229, 0.00316229])}




.. GENERATED FROM PYTHON SOURCE LINES 114-115

Run the sim

.. GENERATED FROM PYTHON SOURCE LINES 115-119

.. code-block:: Python
   :lineno-start: 115

    for i in range(5):
        model.timestep()
        append_to_history()





.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    ---------------- t = 0, dt = 0.1305431643141646 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 735 min = 735                              [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 735 min = 735                         [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 735
        max = 735
        avg = 735
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 45.20 us   (4.5%)
       patch tree reduce : 8.03 us    (0.8%)
       gen split merge   : 791.00 ns  (0.1%)
       split / merge op  : 0/0
       apply split merge : 1002.00 ns (0.1%)
       LB compute        : 933.37 us  (92.2%)
       LB move op cnt    : 0
       LB apply          : 5.01 us    (0.5%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 4.91 us    (73.8%)  
    Warning: High interface/patch volume ratio.                                  [InterfaceGen][rank=0]
        This can lead to high mpi overhead, try to increase the patch split crit
        patch 0 high interf/patch volume: 0.6585034013605442  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 2.245684529942307e-12, max = 9.93195110855951e-07
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (-735.0000000000001,-735,-735)
        sum a = (4.336808689942018e-19,-6.505213034913027e-19,-2.168404344971009e-19)
        sum e = 1837.5000000169691
        sum de = -1.734723475976807e-18  
    Info: cfl dt = 4.438475603539535 cfl multiplier : 0.34                         [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) |  MPI   | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    2.6026e+04    |         735 |   2.824e-02   |    0 % |   3 % |   29.24 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 16641.056772387747 (tsim/hr)                            [sph::Model][rank=0] 
    adding ->  xyz
    adding ->  vxyz
    adding ->  axyz
    adding ->  axyz_ext
    adding ->  hpart
    adding ->  part_id
    adding ->  uint
    adding ->  duint
    adding ->  alpha_AV
    adding ->  divv
    adding ->  dtdivv
    adding ->  curlv
    adding ->  soundspeed
    ---------------- t = 0.1305431643141646, dt = 4.438475603539535 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 735 min = 735                              [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 735 min = 735                         [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 735
        max = 735
        avg = 735
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 8.00 us    (1.9%)
       patch tree reduce : 1342.00 ns (0.3%)
       gen split merge   : 511.00 ns  (0.1%)
       split / merge op  : 0/0
       apply split merge : 902.00 ns  (0.2%)
       LB compute        : 402.72 us  (94.6%)
       LB move op cnt    : 0
       LB apply          : 4.66 us    (1.1%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 3.61 us    (76.0%)  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 1.9109004222813426e-12, max = 9.680958492297962e-07
      iterations = 2  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (-735.0000000000001,-735.0000000000001,-734.9999999999998)
        sum a = (6.505213034913027e-19,8.673617379884035e-19,-2.168404344971009e-19)
        sum e = 1837.5000196165295
        sum de = 2.6020852139652106e-18  
    Info: cfl dt = 7.326603651510656 cfl multiplier : 0.56                         [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) |  MPI   | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    3.3418e+04    |         735 |   2.199e-02   |    0 % |   1 % |   29.24 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 726495.9263218308 (tsim/hr)                             [sph::Model][rank=0] 
    adding ->  xyz
    adding ->  vxyz
    adding ->  axyz
    adding ->  axyz_ext
    adding ->  hpart
    adding ->  part_id
    adding ->  uint
    adding ->  duint
    adding ->  alpha_AV
    adding ->  divv
    adding ->  dtdivv
    adding ->  curlv
    adding ->  soundspeed
    ---------------- t = 4.5690187678536995, dt = 7.326603651510656 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 735 min = 735                              [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 735 min = 735                         [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 735
        max = 735
        avg = 735
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 4.43 us    (1.2%)
       patch tree reduce : 742.00 ns  (0.2%)
       gen split merge   : 561.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 932.00 ns  (0.3%)
       LB compute        : 356.27 us  (95.6%)
       LB move op cnt    : 0
       LB apply          : 2.92 us    (0.8%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.71 us    (69.5%)  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 2.558767171371376e-12, max = 8.71791583137802e-07
      iterations = 2  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (-735.0000000000002,-735,-735)
        sum a = (4.336808689942018e-19,1.0842021724855044e-19,-3.2526065174565133e-19)
        sum e = 1837.500053070114
        sum de = 8.673617379884035e-19  
    Info: cfl dt = 7.86752877531102 cfl multiplier : 0.7066666666666667            [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) |  MPI   | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    3.5277e+04    |         735 |   2.083e-02   |    0 % |   1 % |   29.24 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 1265944.09953616 (tsim/hr)                              [sph::Model][rank=0] 
    adding ->  xyz
    adding ->  vxyz
    adding ->  axyz
    adding ->  axyz_ext
    adding ->  hpart
    adding ->  part_id
    adding ->  uint
    adding ->  duint
    adding ->  alpha_AV
    adding ->  divv
    adding ->  dtdivv
    adding ->  curlv
    adding ->  soundspeed
    ---------------- t = 11.895622419364354, dt = 7.86752877531102 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 735 min = 735                              [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 735 min = 735                         [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 735
        max = 735
        avg = 735
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 4.08 us    (1.0%)
       patch tree reduce : 952.00 ns  (0.2%)
       gen split merge   : 501.00 ns  (0.1%)
       split / merge op  : 0/0
       apply split merge : 922.00 ns  (0.2%)
       LB compute        : 372.84 us  (96.0%)
       LB move op cnt    : 0
       LB apply          : 2.92 us    (0.8%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.65 us    (71.4%)  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 2.284386701783725e-12, max = 9.857809869532035e-07
      iterations = 3  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (-735,-735.0000000000001,-735)
        sum a = (-1.3010426069826053e-18,-1.0842021724855044e-19,-4.336808689942018e-19)
        sum e = 1837.5000585540129
        sum de = -1.734723475976807e-18  
    Info: cfl dt = 6.975215125196861 cfl multiplier : 0.8044444444444444           [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) |  MPI   | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    3.4886e+04    |         735 |   2.107e-02   |    0 % |   1 % |   29.24 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 1344310.5840716779 (tsim/hr)                            [sph::Model][rank=0] 
    adding ->  xyz
    adding ->  vxyz
    adding ->  axyz
    adding ->  axyz_ext
    adding ->  hpart
    adding ->  part_id
    adding ->  uint
    adding ->  duint
    adding ->  alpha_AV
    adding ->  divv
    adding ->  dtdivv
    adding ->  curlv
    adding ->  soundspeed
    ---------------- t = 19.763151194675373, dt = 6.975215125196861 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 735 min = 735                              [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 735 min = 735                         [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 735
        max = 735
        avg = 735
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 5.18 us    (1.5%)
       patch tree reduce : 811.00 ns  (0.2%)
       gen split merge   : 582.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 912.00 ns  (0.3%)
       LB compute        : 336.83 us  (95.3%)
       LB move op cnt    : 0
       LB apply          : 2.96 us    (0.8%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.90 us    (70.7%)  
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 1.829180327679203e-12, max = 9.971895314125504e-07
      iterations = 3  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (-735.0000000000001,-734.9999999999999,-735.0000000000001)
        sum a = (-1.0842021724855044e-18,3.2526065174565133e-19,2.168404344971009e-19)
        sum e = 1837.5000419977805
        sum de = 8.673617379884035e-19  
    Info: cfl dt = 6.38598948340674 cfl multiplier : 0.8696296296296296            [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) |  MPI   | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    3.2797e+04    |         735 |   2.241e-02   |    0 % |   1 % |   29.24 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 1120495.7860532475 (tsim/hr)                            [sph::Model][rank=0] 
    adding ->  xyz
    adding ->  vxyz
    adding ->  axyz
    adding ->  axyz_ext
    adding ->  hpart
    adding ->  part_id
    adding ->  uint
    adding ->  duint
    adding ->  alpha_AV
    adding ->  divv
    adding ->  dtdivv
    adding ->  curlv
    adding ->  soundspeed




.. GENERATED FROM PYTHON SOURCE LINES 120-121

Plot particles history

.. GENERATED FROM PYTHON SOURCE LINES 121-158

.. code-block:: Python
   :lineno-start: 121

    import matplotlib.pyplot as plt
    import numpy as np
    from mpl_toolkits.mplot3d import Axes3D

    fig = plt.figure()
    ax = fig.add_subplot(111, projection="3d")

    for i in range(len(part_history)):
        ax.plot(part_history[i]["x"], part_history[i]["y"], part_history[i]["z"], ".-", lw=0.2)

    ax.set_xlabel("X")
    ax.set_ylabel("Y")
    ax.set_zlabel("Z")

    ax.set_xlim(-4, 4)
    ax.set_ylim(-4, 4)
    ax.set_zlim(-4, 4)


    fig = plt.figure()
    ax = fig.add_subplot(111, projection="3d")

    ax.plot(part_history[0]["x"], part_history[0]["y"], part_history[0]["z"], ".-", lw=0.5, label="0")
    ax.plot(part_history[1]["x"], part_history[1]["y"], part_history[1]["z"], ".-", lw=0.5, label="1")
    ax.plot(part_history[2]["x"], part_history[2]["y"], part_history[2]["z"], ".-", lw=0.5, label="2")

    ax.set_xlabel("X")
    ax.set_ylabel("Y")
    ax.set_zlabel("Z")

    ax.set_xlim(-4, 4)
    ax.set_ylim(-4, 4)
    ax.set_zlim(-4, 4)

    ax.legend()

    plt.show()



.. rst-class:: sphx-glr-horizontal


    *

      .. image-sg:: /_as_gen/sph/images/sphx_glr_run_track_particles_001.png
         :alt: run track particles
         :srcset: /_as_gen/sph/images/sphx_glr_run_track_particles_001.png
         :class: sphx-glr-single-img

    *

      .. image-sg:: /_as_gen/sph/images/sphx_glr_run_track_particles_002.png
         :alt: run track particles
         :srcset: /_as_gen/sph/images/sphx_glr_run_track_particles_002.png
         :class: sphx-glr-single-img






.. rst-class:: sphx-glr-timing

   **Total running time of the script:** (0 minutes 1.919 seconds)

**Estimated memory usage:**  67 MB


.. _sphx_glr_download__as_gen_sph_run_track_particles.py:

.. only:: html

  .. container:: sphx-glr-footer sphx-glr-footer-example

    .. container:: sphx-glr-download sphx-glr-download-jupyter

      :download:`Download Jupyter notebook: run_track_particles.ipynb <run_track_particles.ipynb>`

    .. container:: sphx-glr-download sphx-glr-download-python

      :download:`Download Python source code: run_track_particles.py <run_track_particles.py>`

    .. container:: sphx-glr-download sphx-glr-download-zip

      :download:`Download zipped: run_track_particles.zip <run_track_particles.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
